summaryrefslogtreecommitdiff
path: root/packaging
diff options
context:
space:
mode:
authorMichael Adam <obnox@samba.org>2008-09-04 14:09:15 +0200
committerKarolin Seeger <kseeger@samba.org>2008-09-11 14:02:19 +0200
commit9417b44f107da2b4c8a608f051cd6e6eee3a565b (patch)
tree12e9d32d7feaf0e3bef78e89949a23bd51ea8a1a /packaging
parentec9de64aaba080d58a9771ca4f0eae014d2b244e (diff)
downloadsamba-9417b44f107da2b4c8a608f051cd6e6eee3a565b.tar.gz
packaging(RHEL-CTDB): rename SRCDIR to RPMSRCDIR
Michael (cherry picked from commit d8a8ea87439315ecf407a866a12e2993343af39c) (cherry picked from commit d1fa6c45cdce6d436f83dcf19b07d56cf779911e)
Diffstat (limited to 'packaging')
-rwxr-xr-xpackaging/RHEL-CTDB/makerpms.sh10
1 files changed, 5 insertions, 5 deletions
diff --git a/packaging/RHEL-CTDB/makerpms.sh b/packaging/RHEL-CTDB/makerpms.sh
index 485c810bdbb..94792399687 100755
--- a/packaging/RHEL-CTDB/makerpms.sh
+++ b/packaging/RHEL-CTDB/makerpms.sh
@@ -17,9 +17,9 @@
EXTRA_OPTIONS="$1"
SPECDIR=`rpm --eval %_specdir`
-SRCDIR=`rpm --eval %_sourcedir`
+RPMSRCDIR=`rpm --eval %_sourcedir`
-# At this point the SPECDIR and SRCDIR variables must have a value!
+# At this point the SPECDIR and RPMSRCDIR variables must have a value!
DIRNAME=$(dirname $0)
@@ -44,7 +44,7 @@ esac
pushd ${DIRNAME}/../..
echo -n "Creating samba-${VERSION}.tar.bz2 ... "
-git archive --prefix=samba-${VERSION}/ HEAD | bzip2 > ${SRCDIR}/samba-${VERSION}.tar.bz2
+git archive --prefix=samba-${VERSION}/ HEAD | bzip2 > ${RPMSRCDIR}/samba-${VERSION}.tar.bz2
RC=$?
popd
echo "Done."
@@ -58,13 +58,13 @@ fi
## copy additional source files
##
if [ "x${DOCS_TARBALL}" != "x" ] && [ -f ${DOCS_TARBALL} ]; then
- cp ${DOCS_TARBALL} ${SRCDIR}/${DOCS}
+ cp ${DOCS_TARBALL} ${RPMSRCDIR}/${DOCS}
fi
pushd ${DIRNAME}
chmod 755 setup/filter-requires-samba.sh
-tar --exclude=.svn -jcvf - setup > ${SRCDIR}/setup.tar.bz2
+tar --exclude=.svn -jcvf - setup > ${RPMSRCDIR}/setup.tar.bz2
cp -p ${SPECFILE} ${SPECDIR}